aboutsummaryrefslogtreecommitdiff
path: root/lib/netdev-provider.h
diff options
context:
space:
mode:
authorPravin B Shelar <pshelar@nicira.com>2012-03-22 10:58:32 -0700
committerPravin B Shelar <pshelar@nicira.com>2012-03-22 10:58:32 -0700
commit2c2ea5a88a12ea3bfb003a37f7ec2c2446539a7c (patch)
treeea8aacfd239fc5ae07e30e11ba8e1ec2eaea0b6d /lib/netdev-provider.h
parentece72d2415c62548751ba7276e5ca5e2dde11c04 (diff)
netdev: Rename netdev->get_status() to netdev->get_drv_info().
get_status actually returns driver information, so get_drv_info() is better name. Signed-off-by: Pravin B Shelar <pshelar@nicira.com>
Diffstat (limited to 'lib/netdev-provider.h')
-rw-r--r--lib/netdev-provider.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/netdev-provider.h b/lib/netdev-provider.h
index dea171db..daf46ade 100644
--- a/lib/netdev-provider.h
+++ b/lib/netdev-provider.h
@@ -540,10 +540,10 @@ struct netdev_class {
int (*get_next_hop)(const struct in_addr *host, struct in_addr *next_hop,
char **netdev_name);
- /* Retrieves the status of the device.
+ /* Retrieves driver information of the device.
*
* Populates 'sh' with key-value pairs representing the status of the
* device. A device's status is a set of key-value string pairs
* representing netdev type specific information. For more information see
* ovs-vswitchd.conf.db(5).
*
@@ -552,7 +552,7 @@ struct netdev_class {
*
* This function may be set to null if it would always return EOPNOTSUPP
* anyhow. */
- int (*get_status)(const struct netdev *netdev, struct shash *sh);
+ int (*get_drv_info)(const struct netdev *netdev, struct shash *sh);
/* Looks up the ARP table entry for 'ip' on 'netdev' and stores the
* corresponding MAC address in 'mac'. A return value of ENXIO, in
@@ -540,10 +540,10 @@ struct netdev_class {
*
* Populates 'sh' with key-value pairs representing the status of the
- * device. A device's status is a set of key-value string pairs
+ * device. Driver info is a set of key-value string pairs
* representing netdev type specific information. For more information see
* ovs-vswitchd.conf.db(5).